==> haskell-hslua-module-path-1.1.1-95.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-path.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-path
version:              1.1.1
visibility:           public
id:                   hslua-module-path-1.1.1-GzBFpDAFyHC43uhhnTcBac
key:                  hslua-module-path-1.1.1-GzBFpDAFyHC43uhhnTcBac
license:              MIT
copyright:            © 2020-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with file paths.
description:
    Lua module to work with file paths in a platform
    independent way.

category:             Foreign
abi:                  3cf280df636aab8f2405955565f1978b
exposed:              True
exposed-modules:      HsLua.Module.Path
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-module-path-1.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-module-path-1.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-module-path-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-path
hs-libraries:         HShslua-module-path-1.1.1-GzBFpDAFyHC43uhhnTcBac
depends:
    base-4.18.2.1 filepath-1.4.300.1
    hslua-core-2.3.2-LsuRv5joEv2BEnjW1fCbrM
    hslua-marshalling-2.3.1-2wvb5zI3Ais62iyLUWMiUH
    hslua-packaging-2.3.1-CX7lhwYsgw0Jci7JtzHprm text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-path/html/hslua-module-path.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-path/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-path-1.1.1-96-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-path.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-path
version:              1.1.1
visibility:           public
id:                   hslua-module-path-1.1.1-6Rq40iEdRpdCUQBEnBPksz
key:                  hslua-module-path-1.1.1-6Rq40iEdRpdCUQBEnBPksz
license:              MIT
copyright:            © 2020-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with file paths.
description:
    Lua module to work with file paths in a platform
    independent way.

category:             Foreign
abi:                  6f216ae5de32c282a48eebf26afe2adb
exposed:              True
exposed-modules:      HsLua.Module.Path
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-module-path-1.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-module-path-1.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-module-path-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-path
hs-libraries:         HShslua-module-path-1.1.1-6Rq40iEdRpdCUQBEnBPksz
depends:
    base-4.18.2.1 filepath-1.4.300.1
    hslua-core-2.3.2-6IHXwFbRgmjH5Bn36TUerg
    hslua-marshalling-2.3.1-Lphd68rczTTD9xcjuNYtYD
    hslua-packaging-2.3.1-4anfJzyA7OLGShitXl91KS text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-path/html/hslua-module-path.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-path/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
